@@ -2,9 +2,10 @@
 # @Time    : 2024/2/7 上午11:57
 # @Author  : sudoskys
 # @File    : login.py
-# @Software: PyCharm
-from pydantic import BaseModel
 
 
-class LoginResp(BaseModel):
+from ..schema import RespBase
+
+
+class LoginResp(RespBase):
     accessToken: str
