@@ -2,10 +2,13 @@
 # @Time    : 2024/1/26 上午10:51
 # @Author  : sudoskys
 # @File    : __init__.py.py
-# @Software: PyCharm
 
+
+from .ai.augment_image import AugmentImageInfer  # noqa 401
+from .ai.generate import LLM, LLMResp  # noqa 401
 from .ai.generate_image import GenerateImageInfer, ImageGenerateResp  # noqa 401
 from .ai.generate_image.suggest_tags import SuggestTags, SuggestTagsResp  # noqa 401
+from .ai.generate_stream import LLMStream, LLMStreamResp  # noqa 401
 from .ai.generate_voice import VoiceGenerate, VoiceResponse  # noqa 401
 from .ai.upscale import Upscale, UpscaleResp  # noqa 401
 from .user.information import Information, InformationResp  # noqa 401
