@@ -2,7 +2,7 @@
 # @Time    : 2024/1/30 下午11:52
 # @Author  : sudoskys
 # @File    : test_server_run.py
-# @Software: PyCharm
+
 
 from unittest.mock import patch
 
@@ -29,7 +29,7 @@ def test_subscription_without_api_key(mock_subscription):
 @patch('src.novelai_python.server.GenerateImageInfer')
 def test_generate_image_without_api_key(mock_generate_image):
     mock_generate_image.return_value.request.return_value = {"status": "image generated"}
-    response = client.post("/ai/generate_image")
+    response = client.post("/ai/generate-image")
     assert response.status_code == 403
 
 
